# A set of data processing tools
* databaseProcessors:= for interacting with DBs from python
* fileProcessors:= used for file manipulation in a basic sense
* JSON_TOOLS:= use for generating and reading json files
